summaryrefslogtreecommitdiffstats
path: root/source/OSSupport/Socket.h
diff options
context:
space:
mode:
authormadmaxoft <madmaxoft@0a769ca7-a7f5-676a-18bf-c427514a06d6>2013-03-05 14:35:19 +0100
committermadmaxoft <madmaxoft@0a769ca7-a7f5-676a-18bf-c427514a06d6>2013-03-05 14:35:19 +0100
commitfcdc68fd8e777fa4c852acf7e471de914e4d7ee7 (patch)
treebf1dc6ab80930c8bee3d08375539517fc6a2845b /source/OSSupport/Socket.h
parentFixed logic in socketthreads connecting (diff)
downloadcuberite-fcdc68fd8e777fa4c852acf7e471de914e4d7ee7.tar
cuberite-fcdc68fd8e777fa4c852acf7e471de914e4d7ee7.tar.gz
cuberite-fcdc68fd8e777fa4c852acf7e471de914e4d7ee7.tar.bz2
cuberite-fcdc68fd8e777fa4c852acf7e471de914e4d7ee7.tar.lz
cuberite-fcdc68fd8e777fa4c852acf7e471de914e4d7ee7.tar.xz
cuberite-fcdc68fd8e777fa4c852acf7e471de914e4d7ee7.tar.zst
cuberite-fcdc68fd8e777fa4c852acf7e471de914e4d7ee7.zip
Diffstat (limited to 'source/OSSupport/Socket.h')
-rw-r--r--source/OSSupport/Socket.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/source/OSSupport/Socket.h b/source/OSSupport/Socket.h
index 7c051d229..ddaf7d8c0 100644
--- a/source/OSSupport/Socket.h
+++ b/source/OSSupport/Socket.h
@@ -77,8 +77,11 @@ public:
/// Sets the socket to listen for incoming connections. Returns true if successful.
bool Listen(int a_Backlog = DEFAULT_BACKLOG);
- /// Accepts an incoming connection. Blocks if none available.
- cSocket Accept();
+ /// Accepts an IPv4 incoming connection. Blocks if none available.
+ cSocket AcceptIPv4(void);
+
+ /// Accepts an IPv6 incoming connection. Blocks if none available.
+ cSocket AcceptIPv6(void);
/// Connects to a localhost socket on the specified port using IPv4; returns true if successful.
bool ConnectToLocalhostIPv4(unsigned short a_Port);